TemplatePack

Struct TemplatePack 

pub struct TemplatePack { /* private fields */ }
Example pack joining vocabulary, handlers, dependencies, and a runtime handle.

See crates/khive-pack-template/docs/api/pack-scaffold.md.

Implementations

Source

impl TemplatePack

pub fn new(runtime: KhiveRuntime) -> Self

Bind the template pack to the runtime used by its handlers.