pub struct TemplatePack { /* private fields */ }Expand description
Example pack joining vocabulary, handlers, dependencies, and a runtime handle.
See crates/khive-pack-template/docs/api/pack-scaffold.md.
Implementations
Sourceimpl TemplatePack
impl TemplatePack
Sourcepub fn new(runtime: KhiveRuntime) -> Self
pub fn new(runtime: KhiveRuntime) -> Self
Bind the template pack to the runtime used by its handlers.